@@ -558,10 +558,8 @@ static OP *ckcall_wrapper_func_listassoc_scalars(pTHX_ OP *op, GV *namegv, SV *c
   int argcount = 0;
   OP *nextkid;
   while(kid && (nextkid = OpSIBLING(kid))) {
-    if(!op_yields_oneval(kid)) {
-      op = ck_entersub_args_proto_or_list(op, namegv, &PL_sv_undef);
-      return op;
-    }
+    if(!op_yields_oneval(kid))
+      goto no_wrapper;
 
     argcount++;
     lastarg = kid;
@@ -569,6 +567,11 @@ static OP *ckcall_wrapper_func_listassoc_scalars(pTHX_ OP *op, GV *namegv, SV *c
   }
   /* kid now points at final op which is the gvop of the OP_ENTERSUB */
 
+  if(!argcount) {
+    op_free(op);
+    return newLISTOP_CUSTOM(hd->hooks->ppaddr, 0, NULL, NULL);
+  }
+
   /* Splice out the args list and throw away the old optree */
   OpMORESIB_set(pushmark, kid);
   op_free(op);
@@ -584,6 +587,10 @@ static OP *ckcall_wrapper_func_listassoc_scalars(pTHX_ OP *op, GV *namegv, SV *c
   OpLASTSIB_set(lastarg, op);
 
   return op;
+
+no_wrapper:
+  op = ck_entersub_args_proto_or_list(op, namegv, &PL_sv_undef);
+  return op;
 }
 
 static OP *ckcall_wrapper_func_listassoc_lists(pTHX_ OP *op, GV *namegv, SV *ckobj)
@@ -609,10 +616,8 @@ static OP *ckcall_wrapper_func_listassoc_lists(pTHX_ OP *op, GV *namegv, SV *cko
   int argcount = 0;
   OP *nextkid;
   while(kid && (nextkid = OpSIBLING(kid))) {
-    if(!op_yields_oneval(kid)) {
-      op = ck_entersub_args_proto_or_list(op, namegv, &PL_sv_undef);
-      return op;
-    }
+    if(!op_yields_oneval(kid))
+      goto no_wrapper;
 
     argcount++;
     lastarg = kid;
@@ -620,6 +625,11 @@ static OP *ckcall_wrapper_func_listassoc_lists(pTHX_ OP *op, GV *namegv, SV *cko
   }
   /* kid now points at final op which is the gvop of the OP_ENTERSUB */
 
+  if(!argcount) {
+    op_free(op);
+    return newLISTOP_CUSTOM(hd->hooks->ppaddr, 0, NULL, NULL);
+  }
+
   /* Splice out the args list and throw away the old optree */
   OpMORESIB_set(pushmark, kid);
   OpLASTSIB_set(lastarg, NULL);
@@ -657,6 +667,10 @@ static OP *ckcall_wrapper_func_listassoc_lists(pTHX_ OP *op, GV *namegv, SV *cko
   OpLASTSIB_set(lastarg, op);
 
   return op;
+
+no_wrapper:
+  op = ck_entersub_args_proto_or_list(op, namegv, &PL_sv_undef);
+  return op;
 }
 
 static OP *pp_push_defav_with_count(pTHX)
